@@ -68,7 +68,8 @@ test_parser (GMimeStream *stream)
 	g_mime_parser_set_header_regex (parser, "^X-Evolution$", header_cb, NULL);
 	
 	while (!g_mime_parser_eos (parser)) {
-		message = g_mime_parser_construct_message (parser);
+		if (!(message = g_mime_parser_construct_message (parser)))
+			continue;
 		
 		from = g_mime_parser_get_from (parser);
 		fprintf (stdout, "%s\n", from);
@@ -120,8 +121,7 @@ int main (int argc, char **argv)
 #endif
 	
 #ifdef STREAM_BUFFER
-	istream = g_mime_stream_buffer_new (stream,
-					    GMIME_STREAM_BUFFER_BLOCK_READ);
+	istream = g_mime_stream_buffer_new (stream, GMIME_STREAM_BUFFER_BLOCK_READ);
 	g_object_unref (stream);
 	stream = istream;
 #endif
